offline-cdn
================

A nice way to allow for online-offline development, but also use cdn's for package dependencies.

`Read the documentation <http://django-offlinecdn.readthedocs.org/en/latest/>`__.

|Build Status| |Version| |Downloads| |Test Coverage| |Documentation Status|

.. |Build Status| image:: https://travis-ci.org/gabegaster/django-offlinecdn.svg?branch=master
   :target: https://travis-ci.org/gabegaster/django-offlinecdn
.. |Version| image:: https://pypip.in/v/django-offlinecdn/badge.png
   :target: https://warehouse.python.org/project/django-offlinecdn/
.. |Downloads| image:: https://pypip.in/d/django-offlinecdn/badge.png
   :target: https://warehouse.python.org/project/django-offlinecdn/
.. |Test Coverage| image:: https://coveralls.io/repos/gabegaster/django-offlinecdn/badge.png
   :target: https://coveralls.io/r/gabegaster/django-offlinecdn

.. |Documentation Status| image:: https://readthedocs.org/projects/django-offlinecdn/badge/?version=latest
   :target: https://readthedocs.org/projects/django-offlinecdn/?badge=latest
